@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package HTTP::BrowserDetect;
-$HTTP::BrowserDetect::VERSION = '2.03';
+$HTTP::BrowserDetect::VERSION = '2.04';
 use vars qw(@ALL_TESTS);
 
 # Operating Systems
@@ -324,7 +324,7 @@ sub new {
         $user_agent = $ENV{'HTTP_USER_AGENT'};
     }
 
-    $self->{user_agent} = $user_agent // '';
+    $self->{user_agent} = defined $user_agent ? $user_agent : '';
     $self->_init_core;
 
     return $self;
@@ -2404,7 +2404,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 2.03
+version 2.04
 
 =head1 SYNOPSIS
 
